#
# spec file for package python-hvac
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-hvac
Version:        1.1.0
Release:        1.4
Summary:        HashiCorp Vault API client
License:        BSD-3-Clause
URL:            https://github.com/ianunruh/hvac
Source:         https://github.com/hvac/hvac/archive/v%{version}.tar.gz
BuildRequires:  %{python_module Authlib}
BuildRequires:  %{python_module Flask-SQLAlchemy}
BuildRequires:  %{python_module Flask}
BuildRequires:  %{python_module Werkzeug}
BuildRequires:  %{python_module jwcrypto}
BuildRequires:  %{python_module parameterized}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pyhcl >= 0.3.10}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.21.0}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyhcl >= 0.3.10
Requires:       python-requests >= 2.21.0
BuildArch:      noarch
%python_subpackages

%description
HashiCorp Vault API client for Python 2/3

%prep
%autosetup -p1 -n hvac-%{version}
# doctests and ldap need set up ldap server and that is quite an effort
rm -r tests/doctest/
rm tests/integration_tests/api/auth_methods/test_ldap.py
find hvac -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.* CHANGELOG.*
%license LICENSE.txt
%{python_sitelib}/hvac*

%changelog
* Fri Mar 10 2023 pgajdos@suse.com
- version update to 1.1.0
  * python-six is not required
  * drop python 2 support
  * lot of changes, see CHANGELOG.md or
    https://github.com/hvac/hvac/blob/develop/CHANGELOG.md
- deleted patches
  - remove-mock.patch (upstreamed)
* Tue Aug  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove patch python-hvac-no-mock.patch
- Add patch remove-mock.patch, from upstream.
- Remove unneeded BuildRequires on mock
* Mon May  2 2022 pgajdos@suse.com
- added patches
  fix https://github.com/hvac/hvac/issues/582
  + python-hvac-no-mock.patch
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.11.2:
  * Breakfix release to revert some unintended post-1.0 requirements changes.
  * Revert `six` & `requests` Requirements Changes. GH-768
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- Update to 0.11.0
  * This is intended to by the last hvac release supporting Python 2.7.
  * Userpass: Add use_token param on login(), Accept passthrough **kwargs on create user.
  * Support CA-related Environment Variables.
  * Allow Omission of Password Argument on Userpass create_or_update_user().
  * Add deprecation notices for some Client() methods.
* Thu Jun 17 2021 Dirk Müller <dmueller@suse.com>
- udpate to 0.10.14:
  * Python 2.7: Drop Trailing Comma In `Cert.login()`.
  * Refactor `Cert.login()` Conditional for Python 2.7 Syntax Support.
  * Add default to `group_type` argument in `update_group` and `create_or_update_group_by_name`.
  * Add Certificate Authentication Methods.
  * Expand Transform class to include new(ish) tokenization methods.
  * Add `delete_version_after` KvV2 Param - `configure()` / `update_metadata().
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10.10:
  - AWS Secrets Engine: Add support for iam_tags when creating roles. GH-684
  - Add Active Directory generate credential capability. GH-657
  - Add `policies` Parameter to Userpass `create_or_update_user()` Method. GH-562
  - Add handling of unsupported HTTP methods inside adapter. GH-689
  - Add Convenience `read_secret()` Method for KVv2 Class. GH-686
  - Set daemon attribute instead of using setDaemon method that was deprecated in Python 3.10. GH-688
  - Send AppRole generate_secret_id Method Metadata Parameter as String GH-68
* Thu Apr 22 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10.8:
  - K8s Auth: Allow wildcards for service account and namespace. GH-669
  - Add token_type support to create_kubernetes_role. GH-664
  - Support database secrets static roles. GH-662
* Mon Feb  1 2021 Dirk Müller <dmueller@suse.com>
- update to 0.10.6:
  - Enable response wrapping of PKI secrets. GH-649
  - Fix OIDC login and add working example. GH-638
  - Add rabbitmq vhost_topics parameter. GH-626
  - Expand auth_methods module to support AppRole. GH-637
  - Template "auth method not implemented" error message. GH-651
  - Fix health.py read_health_status GET method. GH-653
  - Fix transit constants for "generate_data_key". GH-632
  - Fix PUT method in secrets engine kv_v1 to use PUT instead of POST. GH-629
  - Remove Erroneous json() Calls In rabbitmq Class. GH-624
* Tue Aug  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.10.5:
  - Add JWT/OIDC Authentication Method Classes. GH-613
  - Add Identity Tokens Methods and Documentation. GH-611
  - Add P-521 to list of allowed key types. GH-608
  - Add P-384 and RSA-3072 to list of allowed key types. GH-606
  - Options not read by tune_mount_configuration. GH-603
  - Add Autodoc Summaries. GH-612
  - Correct Return Type Docstrings Within Transit Class. GH-609
  - Transit engine docs for Encrypt Data now refer to encrypt_data. GH-601
  - Update Vault version test matrix / Oldest Support Vault Version. GH-610
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.10.4:
  - Extract "renew_self_token" from "renew_token". GH-598
  - Add convenience step_down sys backend method. GH-597
* Mon Jun  8 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.10.3:
  - Add Support For use_token_groups In LDAP Auth Method. GH-591
  - Add Raft System Backend Methods. GH-594
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.10.2:
  - Create_role_secret_id: add token_bound_cidrs parameter. GH-585
  - Add vault rekey verification methods. GH-586
  - Add request data to exception objects. GH-583
  - Add marshaling_algorithm to sign/verify params. GH-584
  - Add issuer to kubernetes configuration. GH-575
  - Remove json() calls (unneeded following JSONAdapter addition) GH-589
  - Fix format errors in contributing for HTML docs. GH-577
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.10.1:
  * many various fixes all around
* Wed Feb  6 2019 Marcus Rueckert <mrueckert@suse.de>
- initial package
